==> org-lsst-ccs-subsystem-fcs-buses-4.0.2-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByAutochangerTruck.java <==
package org.lsst.ccs.subsystems.fcs;


/**
 * An object to be published by one AC Truck.
 * Publishes position sensors values.
 * @author virieux
 */
public class StatusDataPublishedByAutochangerTruck extends StatusDataPublishedByFCS {
    private static final long serialVersionUID = 6901144161715675251L;

    private String controllerName;
    private boolean standbySensorValue;
    private boolean handoffSensorValue;
    private boolean onlineSensorValue;
    private boolean standbyInError;
    private boolean handoffInError;
    private boolean onlineInError;
    private int position;
    private boolean controllerInFault;

    public String getControllerName() {
        return controllerName;
    }

    public void setControllerName(String controllerName) {
        this.controllerName = controllerName;
    }
    
    

    public boolean getStandbySensorValue() {
        return standbySensorValue;
    }

    public void setStandbySensorValue(boolean standbySensorValue) {
        this.standbySensorValue = standbySensorValue;
    }

    public boolean getHandoffSensorValue() {
        return handoffSensorValue;
    }

    public void setHandoffSensorValue(boolean handoffSensorValue) {
        this.handoffSensorValue = handoffSensorValue;
    }

    public boolean getOnlineSensorValue() {
        return onlineSensorValue;
    }

    public void setOnlineSensorValue(boolean onlineSensorValue) {
        this.onlineSensorValue = onlineSensorValue;
    }







    public boolean isStandbyInError() {
        return standbyInError;
    }

    public void setStandbyInError(boolean standbyInError) {
        this.standbyInError = standbyInError;
    }

    public boolean isHandoffInError() {
        return handoffInError;
    }

    public void setHandoffInError(boolean handoffInError) {
        this.handoffInError = handoffInError;
    }

    public boolean isOnlineInError() {
        return onlineInError;
    }

    public void setOnlineInError(boolean onlineInError) {
        this.onlineInError = onlineInError;
    }

    public int getPosition() {
        return position;
    }

    public void setPosition(int position) {
        this.position = position;
    }

    public boolean isControllerInFault() {
        return controllerInFault;
    }

    public void setControllerInFault(boolean controllerInFault) {
        this.controllerInFault = controllerInFault;
    }
    
    
}

==> org-lsst-ccs-subsystem-fcs-buses-4.0.12-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByAutochangerTruck.java <==
package org.lsst.ccs.subsystems.fcs;


/**
 * An object to be published by one AC Truck.
 * Publishes position sensors values.
 * @author virieux
 */
public class StatusDataPublishedByAutochangerTruck extends StatusDataPublishedByFCS {
    private static final long serialVersionUID = 6901144161715675251L;

    private String controllerName;
    private boolean standbySensorValue;
    private boolean handoffSensorValue;
    private boolean onlineSensorValue;
    private boolean standbyInError;
    private boolean handoffInError;
    private boolean onlineInError;
    private int position;
    private int current;
    private boolean controllerInFault;

    public String getControllerName() {
        return controllerName;
    }

    public void setControllerName(String controllerName) {
        this.controllerName = controllerName;
    }
    
    

    public boolean getStandbySensorValue() {
        return standbySensorValue;
    }

    public void setStandbySensorValue(boolean standbySensorValue) {
        this.standbySensorValue = standbySensorValue;
    }

    public boolean getHandoffSensorValue() {
        return handoffSensorValue;
    }

    public void setHandoffSensorValue(boolean handoffSensorValue) {
        this.handoffSensorValue = handoffSensorValue;
    }

    public boolean getOnlineSensorValue() {
        return onlineSensorValue;
    }

    public void setOnlineSensorValue(boolean onlineSensorValue) {
        this.onlineSensorValue = onlineSensorValue;
    }

    public boolean isStandbyInError() {
        return standbyInError;
    }

    public void setStandbyInError(boolean standbyInError) {
        this.standbyInError = standbyInError;
    }

    public boolean isHandoffInError() {
        return handoffInError;
    }

    public void setHandoffInError(boolean handoffInError) {
        this.handoffInError = handoffInError;
    }

    public boolean isOnlineInError() {
        return onlineInError;
    }

    public void setOnlineInError(boolean onlineInError) {
        this.onlineInError = onlineInError;
    }

    public int getPosition() {
        return position;
    }

    public void setPosition(int position) {
        this.position = position;
    }

    public boolean isControllerInFault() {
        return controllerInFault;
    }

    public void setControllerInFault(boolean controllerInFault) {
        this.controllerInFault = controllerInFault;
    }

    public int getCurrent() {
        return current;
    }

    public void setCurrent(int current) {
        this.current = current;
    }
}
